@@ -1540,28 +1540,32 @@ print "GOING TO START WEB SERVER\n";
      ______                  _    ,
        / /              /   ' )  /        /
     --/ /_  __.  ____  /_    /  / __ . . /
-   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Trying
+   (_/ / /_(_/|_/ / <_/ <_  (__/_(_)(_/_'   For Using
                              //
 
            _   _      _         _____      _ _    _         _
           | \ | | ___| |_      |  ___|   _| | |  / \  _   _| |_  |
           |  \| |/ _ \ __| o o | |_ | | | | | | / _ \| | | | __/ | \
           | |\  |  __/ |_  o o |  _|| |_| | | |/ ___ \ |_| | ||     |
-          |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ (C)
+          |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright (C) 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
-   eval {
-      local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
-      alarm 15;
+   if (defined $Net::FullAuto::FA_Core::dashboard) {
+      eval {
+         local $SIG{ALRM} = sub { die "alarm\n" }; # \n required
+         alarm 15;
+         print $thanks;
+         print "   \n   Press Any Key to EXIT ... ";
+         <STDIN>;
+      };alarm(0);
+      print "\n\n\n   Please wait at least a minute for the Default Browser\n",
+            "   to start with your new Catalyst© installation!\n\n\n";
+   } else {
       print $thanks;
-      print "   \n   Press Any Key to EXIT ... ";
-      <STDIN>;
-   };alarm(0);
-   print "\n\n\n   Please wait at least a minute for the Default Browser\n",
-         "   to start with your new Catalyst installation!\n\n\n";
+   }
    &Net::FullAuto::FA_Core::cleanup;
 
 };
